import React, { useEffect, useState } from 'react';
import { View, Text, FlatList, ScrollView } from 'react-native';
import { Dropdown } from 'react-native-searchable-dropdown-kj';

import { Header, Loading, PageWrapper } from '../../../../components';
import { getStatistic, ListData, StatisticType } from '../../../../database/statisticsService';
import { ModalStyles } from '../Components/styles';
import { Colors } from '../../../../theme';
import { getFontSize } from '../../../../utils';
import { Image } from 'expo-image';
import { API_HOST } from '../../../../constants';

const NomadsStatistics = ({
  route
}: {
  route: { params: { key: string; title: string; list?: ListData[] | undefined } };
}) => {
  const [data, setData] = useState([]);
  const [selectedValue, setSelectedValue] = useState(route.params.sublist[0].list[0]);

  const [statisticsData, setStatisticsData] = useState<null>();
  function getDataByUrl(url1: string, url2: string | null) {
    const data = getStatistic(url1, url2);
    return JSON.parse(data as unknown as string) as unknown as StatisticType;
  }

  useEffect(() => {
    route.params.sublist?.map((item, index) => {
      item.list?.map((subitem, index) => {
        data.push(subitem);
      });
    });
  }, []);

  useEffect(() => {
    const dataStatistics = getStatistic(selectedValue.url1, selectedValue.url2);
    const tempData = JSON.parse(dataStatistics as unknown as string) as unknown as StatisticType;
    setStatisticsData(tempData);
  }, [selectedValue]);

  if (!selectedValue.url1) return <Loading />;
  if (!statisticsData) return <Loading />;

  const Item = (data: { name: string; flag: string; cnt: number | string; index: number }) => (
    <View
      style={{
        display: 'flex',
        alignItems: 'center',
        flexDirection: 'row',
        flex: 1,
        gap: 8
      }}
    >
      <Text style={{ color: Colors.DARK_BLUE, fontSize: getFontSize(18), fontWeight: '700' }}>
        {data.index + 1}
      </Text>
      <Image
        style={{ width: 36, height: 36, borderRadius: 18 }}
        source={{ uri: API_HOST + '/img/flags_new/' + data.flag }}
      />
      <View
        style={{
          flex: 1,
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'space-between',
          alignItems: 'center'
        }}
      >
        <Text style={{ width: '75%', color: Colors.DARK_BLUE, fontWeight: '700' }}>
          {data.name}
        </Text>
        <Text style={{ color: Colors.DARK_BLUE, fontWeight: '700' }}>{data.cnt}</Text>
      </View>
    </View>
  );

  console.log(statisticsData);

  return (
    <PageWrapper>
      <ScrollView showsVerticalScrollIndicator={false}>
        <Header label={route.params.title} />
        <Dropdown
          style={{
            width: '100%',
            height: 40,
            backgroundColor: '#F9F9F9',
            borderRadius: 4,
            paddingHorizontal: 8
          }}
          placeholderStyle={ModalStyles.placeholderStyle}
          selectedTextStyle={ModalStyles.selectedTextStyle}
          data={data}
          placeholder={'Select'}
          onChange={(obj) => setSelectedValue(obj)}
          value={selectedValue?.url1}
          labelField="name"
          valueField="url1"
        />
        <FlatList
          data={statisticsData.ranking}
          renderItem={({ item, index }) => (
            <View style={{ marginTop: 5, marginBottom: 5 }}>
              <Item
                name={`${item.first_name} ${item.last_name}`}
                flag={item.flag}
                cnt={item.cnt}
                index={index}
              />
            </View>
          )}
        />
      </ScrollView>
    </PageWrapper>
  );
};

export default NomadsStatistics;
